"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectstreesApplication = void 0;
const tslib_1 = require("tslib");
const authentication_1 = require("@loopback/authentication");
const authentication_jwt_1 = require("@loopback/authentication-jwt");
const authorization_1 = require("@loopback/authorization");
const boot_1 = require("@loopback/boot");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const rest_explorer_1 = require("@loopback/rest-explorer");
const service_proxy_1 = require("@loopback/service-proxy");
const path_1 = tslib_1.__importDefault(require("path"));
const application_component_1 = require("./application.component");
const boot_component_1 = require("./boot.component");
const constants_1 = require("./constants");
const db_datasource_1 = require("./datasources/db.datasource");
const constants_2 = require("./interceptors/constants");
const sequence_1 = require("./sequence");
const app_authorization_service_1 = require("./services/app-authorization.service");
const user_authentication_service_1 = require("./services/user-authentication.service");
class ObjectstreesApplication extends boot_1.BootMixin(service_proxy_1.ServiceMixin(repository_1.RepositoryMixin(rest_1.RestApplication))) {
    constructor(options = {}) {
        super(options);
        // Set up the custom sequence
        this.sequence(sequence_1.MySequence);
        // Set up default home page
        this.static('/', path_1.default.join(__dirname, '../public'));
        // Customize @loopback/rest-explorer configuration here
        this.configure(rest_explorer_1.RestExplorerBindings.COMPONENT).to({
            path: '/explorer',
        });
        this.component(rest_explorer_1.RestExplorerComponent);
        //    this.configureFileUpload(options.fileStorageDirectory);
        const destination = path_1.default.join(__dirname, '../.storage');
        this.bind(constants_1.STORAGE_DIRECTORY).to(destination);
        this.bind(rest_1.RestBindings.REQUEST_BODY_PARSER_OPTIONS).to({ limit: '50mb' });
        this.projectRoot = __dirname;
        // Customize @loopback/boot Booter Conventions here
        this.bootOptions = {
            controllers: {
                // Customize ControllerBooter Conventions here
                dirs: ['controllers'],
                extensions: ['.controller.js'],
                nested: true,
            },
        };
        this.bind(core_1.ContextBindings.GLOBAL_INTERCEPTOR_ORDERED_GROUPS).to(constants_2.INTERCEPTORS_ORDER);
        // ------ ADD SNIPPET AT THE BOTTOM ---------
        // Mount authentication system
        this.component(authentication_1.AuthenticationComponent);
        // Mount jwt component
        this.component(authentication_jwt_1.JWTAuthenticationComponent);
        // Bind user and credentials repository
        this.bind(authentication_jwt_1.UserServiceBindings.USER_SERVICE).toClass(user_authentication_service_1.UserAuthenticationService);
        // Bind datasource
        this.dataSource(db_datasource_1.DbDataSource, authentication_jwt_1.UserServiceBindings.DATASOURCE_NAME);
        // ------------- END OF SNIPPET -------------
        const authorizationOptions = {
            precedence: authorization_1.AuthorizationDecision.DENY,
            defaultDecision: authorization_1.AuthorizationDecision.DENY,
        };
        this.configure(authorization_1.AuthorizationBindings.COMPONENT).to(authorizationOptions);
        this.component(authorization_1.AuthorizationComponent);
        this.bind(constants_1.AUTHORIZATION_SERVICE)
            .toProvider(app_authorization_service_1.AppAuthorizationProvider)
            .tag(authorization_1.AuthorizationTags.AUTHORIZER);
        this.bind(rest_1.RestBindings.ERROR_WRITER_OPTIONS).to({
            safeFields: ['errorCode', 'errorArgs', 'name'],
        });
        this.component(application_component_1.ApplicationComponent);
    }
    async boot() {
        await super.boot();
        this.component(boot_component_1.BootComponent);
    }
}
exports.ObjectstreesApplication = ObjectstreesApplication;
ObjectstreesApplication.serverBase = 'http://127.0.0.1:3000/api';
//# sourceMappingURL=application.js.map