"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpressServer = void 0;
const tslib_1 = require("tslib");
const express_1 = tslib_1.__importDefault(require("express"));
const p_event_1 = tslib_1.__importDefault(require("p-event"));
const application_1 = require("./application");
class ExpressServer {
    constructor(options = {}) {
        this.app = express_1.default();
        this.lbApp = new application_1.ObjectstreesApplication(options);
        this.app.use('/api', this.lbApp.requestHandler);
        // Serve static files in the public folder
        this.app.use(express_1.default.static('public'));
    }
    async boot() {
        await this.lbApp.boot();
    }
    async start() {
        await this.lbApp.start();
        const port = this.lbApp.restServer.config.port || 3000;
        const host = this.lbApp.restServer.config.host
            ? this.lbApp.restServer.config.host
            : '127.0.0.1';
        this.server = this.app.listen(port, host);
        console.log('listening', host, port);
        await p_event_1.default(this.server, 'listening');
    }
    // For testing purposes
    async stop() {
        if (!this.server)
            return;
        await this.lbApp.stop();
        this.server.close();
        await p_event_1.default(this.server, 'close');
        this.server = null;
    }
}
exports.ExpressServer = ExpressServer;
//# sourceMappingURL=server.js.map