import { IRestEntity } from '@jacquesparis/objects-model';
import { AuthorizationContext, AuthorizationDecision, AuthorizationMetadata } from '@loopback/authorization';
import { Principal } from '@loopback/security';
import { ObjectNode } from '../../models';
import { EntityName } from './../../models/entity-name';
import { ObjectTree } from './../../models/object-tree.model';
import { ApplicationService, CurrentContext } from './../application.service';
import { ObjectNodeService } from './../object-node.service';
import { ObjectTreeService } from './../object-tree/object-tree.service';
import { ObjectTypeService } from './../object-type.service';
import { AccessRightCRUD, AccessRightPermissions, AccessRightSet, AccessRightsScope } from './access-rights.const';
import { AccessRightsInit } from './access-rights.init';
export interface AccessRightsProvider {
    cleanReturnedEntity(entity: IRestEntity, ctx: CurrentContext): Promise<void>;
    authorize(ctx: CurrentContext, context: AuthorizationContext): Promise<AuthorizationDecision>;
}
export declare class AccessRightsService {
    protected appCtx: ApplicationService;
    protected objectTypeService: ObjectTypeService;
    protected objectNodeService: ObjectNodeService;
    protected objectTreeService: ObjectTreeService;
    private accessRights;
    get ready(): Promise<void>;
    init: AccessRightsInit;
    constructor(appCtx: ApplicationService, objectTypeService: ObjectTypeService, objectNodeService: ObjectNodeService, objectTreeService: ObjectTreeService);
    authorize(ctx: CurrentContext, context: AuthorizationContext, metadata: AuthorizationMetadata): Promise<AuthorizationDecision>;
    cleanReturnedEntity(entityName: EntityName, entity: IRestEntity, ctx: CurrentContext): Promise<void>;
    cleanReturnedEntities(entityName: EntityName, entities: IRestEntity[], ctx: CurrentContext): Promise<void>;
    registerAccessRightsService(resource: EntityName, accessRights: AccessRightsProvider): void;
    getNodeAccessRights(node: ObjectNode, ctx: CurrentContext): Promise<AccessRightCRUD>;
    hasNodeAccessRight(scope: AccessRightsScope, node: ObjectNode, ctx: CurrentContext): Promise<boolean>;
    private loadACLTrees;
    loadRights(node: ObjectNode, ctx: CurrentContext): Promise<AccessRightPermissions>;
    private mergeReset;
    private mergeRight;
    protected computeACLTree(aclTree: ObjectTree, principal: Principal): Promise<{
        reset: AccessRightSet;
        rights: AccessRightSet;
    }>;
    private findMatchingUser;
}
