"use strict";
var ApplicationService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationService = exports.ObjectTypeName = exports.ExpectedValue = exports.CURRENT_CONTEXT = exports.CurrentContext = exports.TypeContext = exports.AccessRightsContext = exports.TreeContext = exports.NodeContext = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
class NodeContext {
    constructor() {
        this.node = new ExpectedValue();
        this.parent = new ExpectedValue();
        this.parentType = new ExpectedValue();
        this.objectSubType = new ExpectedValue();
        this.objectType = new ExpectedValue();
    }
}
exports.NodeContext = NodeContext;
class TreeContext {
    constructor() {
        this.treeNode = new ExpectedValue();
    }
}
exports.TreeContext = TreeContext;
class AccessRightsContext {
    constructor() {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.rights = new ExpectedValue();
        this.user = new ExpectedValue();
        this.treeRootNodeId = new ExpectedValue();
        this.aclTrees = new ExpectedValue();
    }
}
exports.AccessRightsContext = AccessRightsContext;
class TypeContext {
    constructor() {
        this.types = new ExpectedValue();
    }
}
exports.TypeContext = TypeContext;
class CurrentContext {
    constructor() {
        this.nodeContext = new NodeContext();
        this.treeContext = new TreeContext();
        this.accessRightsContexte = new AccessRightsContext();
        this.typeContext = new TypeContext();
    }
    static get(value) {
        const ctx = new CurrentContext();
        if (value) {
            for (const key in value) {
                if (key in ctx) {
                    Object.assign(ctx[key], value[key]);
                }
                else {
                    ctx[key] = value[key];
                }
            }
        }
        return ctx;
    }
}
exports.CurrentContext = CurrentContext;
exports.CURRENT_CONTEXT = 'CURRENT_CONTEXT';
class ExpectedValue {
    constructor(value) {
        this._value = undefined;
        this.waitForValue = new Promise((resolve, reject) => {
            this.resolveValue = resolve;
        });
        if (undefined !== value) {
            this.value = value;
        }
    }
    get value() {
        return this._value;
    }
    set value(value) {
        this._value = value;
        this.resolveValue(this.value);
    }
    async getOrSetValue(searchValue) {
        if (undefined === this.value) {
            this.value = await searchValue();
        }
        return this.value;
    }
}
exports.ExpectedValue = ExpectedValue;
var ObjectTypeName;
(function (ObjectTypeName) {
    ObjectTypeName["ROOT"] = "root";
    ObjectTypeName["USER"] = "User";
    ObjectTypeName["ANONYMOUS_USER"] = "AnonymousUser";
    ObjectTypeName["ACCESS_RIGHT_DEFINITION"] = "AccessRightDefinition";
    ObjectTypeName["ACCESS_RIGHT_GROUP"] = "AccessRightGroup";
    ObjectTypeName["ACCESS_RIGHT_OWNERS"] = "AccessRightOwners";
    ObjectTypeName["ACCESS_RIGHT_ACCESS_MANAGERS"] = "AccessRightAccessManagers";
    ObjectTypeName["TENANT"] = "Tenant";
})(ObjectTypeName = exports.ObjectTypeName || (exports.ObjectTypeName = {}));
let ApplicationService = ApplicationService_1 = class ApplicationService {
    constructor() {
        this.rootType = new ExpectedValue();
        this.tenantType = new ExpectedValue();
        this.rooteNode = new ExpectedValue();
        this.userType = new ExpectedValue();
        this.anonymousUserType = new ExpectedValue();
        this.accessRightsDefinitionType = new ExpectedValue();
        this.accessRightsGroupType = new ExpectedValue();
        this.accessRightsOwnersType = new ExpectedValue();
        this.accessRightsAccessManagersType = new ExpectedValue();
        this.ready = Promise.all([
            this.tenantType.waitForValue,
            this.rootType.waitForValue,
            this.rooteNode.waitForValue,
            this.userType.waitForValue,
            this.anonymousUserType.waitForValue,
            this.accessRightsDefinitionType.waitForValue,
            this.accessRightsGroupType.waitForValue,
            this.accessRightsOwnersType.waitForValue,
            this.accessRightsAccessManagersType.waitForValue,
        ]);
    }
};
ApplicationService.OBJECT_TYPE_NAMES = ObjectTypeName;
ApplicationService.OBJECT_NODE_NAMES = {
    [ApplicationService_1.OBJECT_TYPE_NAMES.ROOT]: 'root',
    [ApplicationService_1.OBJECT_TYPE_NAMES.USER]: 'Admin',
    [ApplicationService_1.OBJECT_TYPE_NAMES.ANONYMOUS_USER]: 'Anonymous User',
    [ApplicationService_1.OBJECT_TYPE_NAMES.ACCESS_RIGHT_DEFINITION]: 'Access Rights',
    [ApplicationService_1.OBJECT_TYPE_NAMES.ACCESS_RIGHT_GROUP]: 'Users group',
    [ApplicationService_1.OBJECT_TYPE_NAMES.ACCESS_RIGHT_OWNERS]: 'Owners group',
    [ApplicationService_1.OBJECT_TYPE_NAMES.ACCESS_RIGHT_ACCESS_MANAGERS]: 'Access Managers group',
    [ApplicationService_1.OBJECT_TYPE_NAMES.TENANT]: 'Tenant',
};
ApplicationService.CONTENT_TYPE = {
    USER: 'ContentUser',
    JSON: '',
};
ApplicationService = ApplicationService_1 = tslib_1.__decorate([
    core_1.bind({ scope: core_1.BindingScope.SINGLETON })
], ApplicationService);
exports.ApplicationService = ApplicationService;
//# sourceMappingURL=application.service.js.map