"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentEntityService = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-explicit-any */
const core_1 = require("@loopback/core");
const application_error_1 = require("./../helper/application-error");
let ContentEntityService = class ContentEntityService {
    constructor( /* Add @inject to inject parameters */) {
        this.contentTypes = {};
    }
    async getContentDefinition(contentType) {
        if (this.hasContentManager(contentType)) {
            return this.contentTypes[contentType].getContentDefinition();
        }
        return { properties: {} };
    }
    hasContentManager(contentType) {
        return contentType && contentType in this.contentTypes;
    }
    registerNewContentType(contentType, service) {
        this.contentTypes[contentType] = service;
    }
    manageContent(contentType, entity, postedEntity) {
        if (contentType && this.hasContentManager(contentType)) {
            return this.contentTypes[contentType].manageContent(entity, postedEntity);
        }
        return Promise.resolve(false);
    }
    addTransientContent(contentType, entity) {
        if (contentType && this.hasContentManager(contentType)) {
            return this.contentTypes[contentType].addTransientContent(entity);
        }
        return Promise.resolve();
    }
    getContent(contentType, entity, fieldName, args) {
        if (contentType && this.hasContentManager(contentType)) {
            return this.contentTypes[contentType].getContent(entity, fieldName, args);
        }
        throw application_error_1.ApplicationError.notFound({ contentType: contentType });
    }
};
ContentEntityService = tslib_1.__decorate([
    core_1.bind({ scope: core_1.BindingScope.SINGLETON }),
    tslib_1.__metadata("design:paramtypes", [])
], ContentEntityService);
exports.ContentEntityService = ContentEntityService;
//# sourceMappingURL=content-entity.service.js.map