"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectTreeInit = void 0;
const application_service_1 = require("./../application.service");
const object_tree_const_1 = require("./object-tree.const");
class ObjectTreeInit {
    constructor(objectNodeService, objectTypeService, contentEntityService, appCtx) {
        this.objectNodeService = objectNodeService;
        this.objectTypeService = objectTypeService;
        this.contentEntityService = contentEntityService;
        this.appCtx = appCtx;
        this.ready = new Promise((resolve, reject) => {
            this.init().then(() => {
                resolve();
            }, (error) => {
                reject(error);
            });
        });
    }
    async init() {
        const rootType = await this.appCtx.rootType.getOrSetValue(async () => {
            let newRootType = await this.objectTypeService.searchByName(application_service_1.ApplicationService.OBJECT_TYPE_NAMES.ROOT);
            if (!newRootType) {
                newRootType = await this.objectTypeService.add(object_tree_const_1.ROOT_TYPE, new application_service_1.CurrentContext());
            }
            return newRootType;
        });
        const tenantType = await this.appCtx.tenantType.getOrSetValue(async () => {
            let newType = await this.objectTypeService.searchByName(application_service_1.ApplicationService.OBJECT_TYPE_NAMES.TENANT);
            if (!newType) {
                newType = await this.objectTypeService.add(object_tree_const_1.TENANT_TYPE, new application_service_1.CurrentContext());
            }
            return newType;
        });
        await this.objectTypeService.getOrCreateObjectSubType(rootType.id, tenantType.id, {
            acl: true,
            name: application_service_1.ApplicationService.OBJECT_TYPE_NAMES.TENANT,
            namespace: true,
            owner: true,
            tree: true,
        });
        await this.appCtx.rooteNode.getOrSetValue(async () => {
            let newRoot = await this.objectNodeService.searchOwner(application_service_1.ApplicationService.OBJECT_TYPE_NAMES.ROOT, application_service_1.ApplicationService.OBJECT_NODE_NAMES[application_service_1.ApplicationService.OBJECT_TYPE_NAMES.ROOT]);
            if (!newRoot) {
                newRoot = await this.objectNodeService.add({
                    name: application_service_1.ApplicationService.OBJECT_NODE_NAMES[application_service_1.ApplicationService.OBJECT_TYPE_NAMES.ROOT],
                    objectTypeId: rootType.id,
                    owner: true,
                    tree: true,
                    namesapce: true,
                    acl: true,
                }, new application_service_1.CurrentContext(), true);
            }
            return newRoot;
        });
    }
}
exports.ObjectTreeInit = ObjectTreeInit;
//# sourceMappingURL=object-tree.init.js.map